import type { ComputedRef, FunctionalComponent, PropType, Ref, SetupContext, VNode } from 'vue';
import type { AutoPlacementOptions, FlipOptions, HideOptions, OffsetOptions, ShiftOptions } from '@floating-ui/core';
import type { AutoUpdateOptions, DetectOverflowOptions, FloatingElement, Middleware, Placement, ReferenceElement, Strategy, VirtualElement } from '@floating-ui/dom';
import type { ClassResolver } from './class-resolvers';
interface ReferenceState {
    referenceRef: Ref<ReferenceElement | null>;
    placement: Readonly<Ref<Placement>>;
}
interface FloatingState {
    floatingRef: Ref<FloatingElement | null>;
    props: FloatProps;
    mounted: Ref<boolean>;
    show: Ref<boolean>;
    referenceHidden: Ref<boolean | undefined>;
    escaped: Ref<boolean | undefined>;
    placement: Readonly<Ref<Placement>>;
    floatingStyles: Ref<{
        position: Strategy;
        top: string;
        left: string;
        transform?: string;
        willChange?: string;
    }>;
    referenceElWidth: Ref<number | null>;
    updateFloating: () => void;
}
interface ArrowState {
    ref: Ref<HTMLElement | null>;
    placement: Ref<Placement>;
    x: Ref<number | undefined>;
    y: Ref<number | undefined>;
}
export interface FloatProps {
    as?: string | FunctionalComponent;
    floatingAs?: string | FunctionalComponent;
    show?: boolean;
    placement?: Placement;
    strategy?: Strategy;
    offset?: OffsetOptions;
    shift?: boolean | number | Partial<ShiftOptions & DetectOverflowOptions>;
    flip?: boolean | number | Partial<FlipOptions & DetectOverflowOptions>;
    arrow?: boolean | number;
    autoPlacement?: boolean | Partial<AutoPlacementOptions & DetectOverflowOptions>;
    hide?: boolean | Partial<HideOptions & DetectOverflowOptions> | Partial<HideOptions & DetectOverflowOptions>[];
    referenceHiddenClass?: string;
    escapedClass?: string;
    autoUpdate?: boolean | Partial<AutoUpdateOptions>;
    zIndex?: number | string;
    vueTransition?: boolean;
    transitionName?: string;
    transitionType?: 'transition' | 'animation';
    enter?: string;
    enterFrom?: string;
    enterTo?: string;
    leave?: string;
    leaveFrom?: string;
    leaveTo?: string;
    originClass?: string | ClassResolver;
    tailwindcssOriginClass?: boolean;
    portal?: boolean;
    transform?: boolean;
    adaptiveWidth?: boolean | {
        attribute?: string;
    };
    composable?: boolean;
    dialog?: boolean;
    middleware?: Middleware[] | ((refs: {
        referenceEl: ComputedRef<ReferenceElement | null>;
        floatingEl: ComputedRef<HTMLElement | null>;
    }) => Middleware[]);
    onShow?: () => any;
    onHide?: () => any;
    onUpdate?: () => any;
}
export declare const FloatPropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    floatingAs: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    show: {
        type: BooleanConstructor;
        default: null;
    };
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    strategy: {
        type: PropType<Strategy>;
        default: string;
    };
    offset: PropType<OffsetOptions>;
    shift: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            limiter: {
                fn: (state: import("@floating-ui/core").MiddlewareState) => import("@floating-ui/utils").Coords;
                options?: any;
            };
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    flip: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            fallbackPlacements: Placement[];
            fallbackStrategy: "bestFit" | "initialPlacement";
            fallbackAxisSideDirection: "start" | "end" | "none";
            flipAlignment: boolean;
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    arrow: {
        type: (NumberConstructor | BooleanConstructor)[];
        default: boolean;
    };
    autoPlacement: {
        type: PropType<boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            crossAxis: boolean;
            alignment: import("@floating-ui/utils").Alignment | null;
            autoAlignment: boolean;
            allowedPlacements: Placement[];
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    hide: {
        type: PropType<boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            strategy: "referenceHidden" | "escaped";
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }> | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            strategy: "referenceHidden" | "escaped";
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>[]>;
        default: boolean;
    };
    referenceHiddenClass: StringConstructor;
    escapedClass: StringConstructor;
    autoUpdate: {
        type: PropType<boolean | Partial<Partial<{
            ancestorScroll: boolean;
            ancestorResize: boolean;
            elementResize: boolean;
            layoutShift: boolean;
            animationFrame: boolean;
        }>>>;
        default: boolean;
    };
    zIndex: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
    };
    vueTransition: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionName: StringConstructor;
    transitionType: PropType<"transition" | "animation">;
    enter: StringConstructor;
    enterFrom: StringConstructor;
    enterTo: StringConstructor;
    leave: StringConstructor;
    leaveFrom: StringConstructor;
    leaveTo: StringConstructor;
    originClass: PropType<string | ClassResolver>;
    tailwindcssOriginClass: {
        type: BooleanConstructor;
        default: boolean;
    };
    portal: {
        type: BooleanConstructor;
        default: boolean;
    };
    transform: {
        type: BooleanConstructor;
        default: boolean;
    };
    adaptiveWidth: {
        type: PropType<boolean | {
            attribute?: string | undefined;
        }>;
        default: boolean;
    };
    composable: {
        type: BooleanConstructor;
        default: boolean;
    };
    dialog: {
        type: BooleanConstructor;
        default: boolean;
    };
    middleware: {
        type: PropType<{
            options?: any;
            name: string;
            fn: (state: {
                x: number;
                y: number;
                strategy: Strategy;
                initialPlacement: Placement;
                placement: Placement;
                middlewareData: import("@floating-ui/core").MiddlewareData;
                rects: import("@floating-ui/utils").ElementRects;
                platform: import("@floating-ui/core").Platform;
                elements: import("@floating-ui/dom").Elements;
            }) => import("@floating-ui/core").MiddlewareReturn | Promise<import("@floating-ui/core").MiddlewareReturn>;
        }[] | ((refs: {
            referenceEl: ComputedRef<ReferenceElement | null>;
            floatingEl: ComputedRef<FloatingElement | null>;
        }) => Middleware[])>;
        default: () => never[];
    };
};
export interface FloatSlotProps {
    placement: Placement;
}
export type RenderReferenceElementProps = FloatReferenceProps & Required<Pick<FloatReferenceProps, 'as'>>;
export declare function renderReferenceElement(referenceNode: VNode, componentProps: RenderReferenceElementProps, attrs: SetupContext['attrs'], context: ReferenceState): VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>;
export type RenderFloatingElementProps = FloatContentProps & Required<Pick<FloatContentProps, 'as'>> & {
    show?: boolean | null;
};
export declare function renderFloatingElement(floatingNode: VNode, componentProps: RenderFloatingElementProps, attrs: SetupContext['attrs'], context: FloatingState): VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>;
export declare function useFloat<T extends ReferenceElement>(show: Ref<boolean>, reference: Ref<T | null>, floating: Ref<FloatingElement | null>, props: FloatProps, emit: (event: 'show' | 'hide' | 'update', ...args: any[]) => void): {
    referenceApi: ReferenceState;
    floatingApi: FloatingState;
    arrowApi: ArrowState;
    placement: Readonly<Ref<Placement>>;
    referenceEl: ComputedRef<T | null>;
    floatingEl: ComputedRef<HTMLElement | null>;
    middlewareData: Readonly<Ref<import("@floating-ui/core").MiddlewareData>>;
    update: () => void;
};
export declare const Float: new () => {
    $props: FloatProps;
    $slots: {
        default(props: FloatSlotProps): any;
    };
};
export interface FloatReferenceProps extends Pick<FloatProps, 'as'> {
}
export declare const FloatReferencePropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
};
export interface FloatReferenceSlotProps {
    placement: Placement;
}
export declare const FloatReference: new () => {
    $props: FloatReferenceProps;
    $slots: {
        default(props: FloatReferenceSlotProps): any;
    };
};
export interface FloatContentProps extends Pick<FloatProps, 'as' | 'vueTransition' | 'transitionName' | 'transitionType' | 'enter' | 'enterFrom' | 'enterTo' | 'leave' | 'leaveFrom' | 'leaveTo' | 'originClass' | 'tailwindcssOriginClass'> {
    transitionChild?: boolean;
}
export declare const FloatContentPropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    vueTransition: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionName: StringConstructor;
    transitionType: PropType<"transition" | "animation">;
    enter: StringConstructor;
    enterFrom: StringConstructor;
    enterTo: StringConstructor;
    leave: StringConstructor;
    leaveFrom: StringConstructor;
    leaveTo: StringConstructor;
    originClass: PropType<string | ClassResolver>;
    tailwindcssOriginClass: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionChild: {
        type: BooleanConstructor;
        default: boolean;
    };
};
export interface FloatContentSlotProps {
    placement: Placement;
}
export declare const FloatContent: new () => {
    $props: FloatContentProps;
    $slots: {
        default(props: FloatContentSlotProps): any;
    };
};
export interface FloatArrowProps extends Pick<FloatProps, 'as'> {
    offset?: number;
}
export declare const FloatArrowPropsValidators: {
    as: {
        default: string;
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
    };
    offset: {
        type: NumberConstructor;
        default: number;
    };
};
export interface FloatArrowSlotProps {
    placement: Placement;
}
export declare const FloatArrow: new () => {
    $props: FloatArrowProps;
    $slots: {
        default(props: FloatArrowSlotProps): any;
    };
};
export interface FloatVirtualProps<FloatingElement = HTMLElement> extends Pick<FloatProps, 'as' | 'show' | 'placement' | 'strategy' | 'offset' | 'shift' | 'flip' | 'arrow' | 'autoPlacement' | 'autoUpdate' | 'zIndex' | 'vueTransition' | 'transitionName' | 'transitionType' | 'enter' | 'enterFrom' | 'enterTo' | 'leave' | 'leaveFrom' | 'leaveTo' | 'originClass' | 'tailwindcssOriginClass' | 'portal' | 'transform' | 'middleware' | 'onShow' | 'onHide' | 'onUpdate'> {
    onInitial?: (props: FloatVirtualInitialProps<FloatingElement>) => any;
}
export declare const FloatVirtualPropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    show: {
        type: BooleanConstructor;
        default: null;
    };
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    strategy: {
        type: PropType<Strategy>;
        default: string;
    };
    offset: PropType<OffsetOptions>;
    shift: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            limiter: {
                fn: (state: import("@floating-ui/core").MiddlewareState) => import("@floating-ui/utils").Coords;
                options?: any;
            };
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    flip: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            fallbackPlacements: Placement[];
            fallbackStrategy: "bestFit" | "initialPlacement";
            fallbackAxisSideDirection: "start" | "end" | "none";
            flipAlignment: boolean;
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    arrow: {
        type: (NumberConstructor | BooleanConstructor)[];
        default: boolean;
    };
    autoPlacement: {
        type: PropType<boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            crossAxis: boolean;
            alignment: import("@floating-ui/utils").Alignment | null;
            autoAlignment: boolean;
            allowedPlacements: Placement[];
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    autoUpdate: {
        type: PropType<boolean | Partial<Partial<{
            ancestorScroll: boolean;
            ancestorResize: boolean;
            elementResize: boolean;
            layoutShift: boolean;
            animationFrame: boolean;
        }>>>;
        default: boolean;
    };
    zIndex: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
    };
    vueTransition: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionName: StringConstructor;
    transitionType: PropType<"transition" | "animation">;
    enter: StringConstructor;
    enterFrom: StringConstructor;
    enterTo: StringConstructor;
    leave: StringConstructor;
    leaveFrom: StringConstructor;
    leaveTo: StringConstructor;
    originClass: PropType<string | ClassResolver>;
    tailwindcssOriginClass: {
        type: BooleanConstructor;
        default: boolean;
    };
    portal: {
        type: BooleanConstructor;
        default: boolean;
    };
    transform: {
        type: BooleanConstructor;
        default: boolean;
    };
    middleware: {
        type: PropType<{
            options?: any;
            name: string;
            fn: (state: {
                x: number;
                y: number;
                strategy: Strategy;
                initialPlacement: Placement;
                placement: Placement;
                middlewareData: import("@floating-ui/core").MiddlewareData;
                rects: import("@floating-ui/utils").ElementRects;
                platform: import("@floating-ui/core").Platform;
                elements: import("@floating-ui/dom").Elements;
            }) => import("@floating-ui/core").MiddlewareReturn | Promise<import("@floating-ui/core").MiddlewareReturn>;
        }[] | ((refs: {
            referenceEl: ComputedRef<ReferenceElement | null>;
            floatingEl: ComputedRef<FloatingElement | null>;
        }) => Middleware[])>;
        default: () => never[];
    };
};
export interface FloatVirtualSlotProps {
    placement: Placement;
    close: () => void;
}
export interface FloatVirtualInitialProps<FloatingElement = HTMLElement> {
    show: Ref<boolean>;
    placement: Readonly<Ref<Placement>>;
    reference: Ref<VirtualElement>;
    floating: Ref<FloatingElement | null>;
}
export declare const FloatVirtual: new () => {
    $props: FloatVirtualProps<any>;
    $slots: {
        default(props: FloatVirtualSlotProps): any;
    };
};
export interface FloatContextMenuProps extends Omit<FloatVirtualProps, 'show' | 'portal'> {
}
export declare const FloatContextMenuPropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    strategy: {
        type: PropType<Strategy>;
        default: string;
    };
    offset: PropType<OffsetOptions>;
    shift: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            limiter: {
                fn: (state: import("@floating-ui/core").MiddlewareState) => import("@floating-ui/utils").Coords;
                options?: any;
            };
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    flip: {
        default: boolean;
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            fallbackPlacements: Placement[];
            fallbackStrategy: "bestFit" | "initialPlacement";
            fallbackAxisSideDirection: "start" | "end" | "none";
            flipAlignment: boolean;
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
    };
    arrow: {
        type: (NumberConstructor | BooleanConstructor)[];
        default: boolean;
    };
    autoPlacement: {
        type: PropType<boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            crossAxis: boolean;
            alignment: import("@floating-ui/utils").Alignment | null;
            autoAlignment: boolean;
            allowedPlacements: Placement[];
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    autoUpdate: {
        type: PropType<boolean | Partial<Partial<{
            ancestorScroll: boolean;
            ancestorResize: boolean;
            elementResize: boolean;
            layoutShift: boolean;
            animationFrame: boolean;
        }>>>;
        default: boolean;
    };
    zIndex: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
    };
    vueTransition: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionName: StringConstructor;
    transitionType: PropType<"transition" | "animation">;
    enter: StringConstructor;
    enterFrom: StringConstructor;
    enterTo: StringConstructor;
    leave: StringConstructor;
    leaveFrom: StringConstructor;
    leaveTo: StringConstructor;
    originClass: PropType<string | ClassResolver>;
    tailwindcssOriginClass: {
        type: BooleanConstructor;
        default: boolean;
    };
    transform: {
        type: BooleanConstructor;
        default: boolean;
    };
    middleware: {
        type: PropType<{
            options?: any;
            name: string;
            fn: (state: {
                x: number;
                y: number;
                strategy: Strategy;
                initialPlacement: Placement;
                placement: Placement;
                middlewareData: import("@floating-ui/core").MiddlewareData;
                rects: import("@floating-ui/utils").ElementRects;
                platform: import("@floating-ui/core").Platform;
                elements: import("@floating-ui/dom").Elements;
            }) => import("@floating-ui/core").MiddlewareReturn | Promise<import("@floating-ui/core").MiddlewareReturn>;
        }[] | ((refs: {
            referenceEl: ComputedRef<ReferenceElement | null>;
            floatingEl: ComputedRef<FloatingElement | null>;
        }) => Middleware[])>;
        default: () => never[];
    };
};
export declare const FloatContextMenu: new () => {
    $props: FloatContextMenuProps;
    $slots: {
        default(props: FloatVirtualSlotProps): any;
    };
};
export interface FloatCursorProps extends Omit<FloatVirtualProps, 'show' | 'portal'> {
    globalHideCursor?: boolean;
}
export declare const FloatCursorPropsValidators: {
    as: {
        type: PropType<string | FunctionalComponent<{}, {}, any, {}>>;
        default: string;
    };
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    strategy: {
        type: PropType<Strategy>;
        default: string;
    };
    offset: PropType<OffsetOptions>;
    shift: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            limiter: {
                fn: (state: import("@floating-ui/core").MiddlewareState) => import("@floating-ui/utils").Coords;
                options?: any;
            };
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    flip: {
        type: PropType<number | boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            mainAxis: boolean;
            crossAxis: boolean;
            fallbackPlacements: Placement[];
            fallbackStrategy: "bestFit" | "initialPlacement";
            fallbackAxisSideDirection: "start" | "end" | "none";
            flipAlignment: boolean;
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    arrow: {
        type: (NumberConstructor | BooleanConstructor)[];
        default: boolean;
    };
    autoPlacement: {
        type: PropType<boolean | Partial<Partial<Partial<{
            boundary: any;
            rootBoundary: import("@floating-ui/core").RootBoundary;
            elementContext: import("@floating-ui/core").ElementContext;
            altBoundary: boolean;
            padding: import("@floating-ui/utils").Padding;
        }> & {
            crossAxis: boolean;
            alignment: import("@floating-ui/utils").Alignment | null;
            autoAlignment: boolean;
            allowedPlacements: Placement[];
        }> & {
            rootBoundary?: import("@floating-ui/core").RootBoundary | undefined;
            elementContext?: import("@floating-ui/core").ElementContext | undefined;
            altBoundary?: boolean | undefined;
            padding?: import("@floating-ui/utils").Padding | undefined;
            boundary?: import("@floating-ui/dom").Boundary | undefined;
        }>>;
        default: boolean;
    };
    autoUpdate: {
        type: PropType<boolean | Partial<Partial<{
            ancestorScroll: boolean;
            ancestorResize: boolean;
            elementResize: boolean;
            layoutShift: boolean;
            animationFrame: boolean;
        }>>>;
        default: boolean;
    };
    zIndex: {
        type: (NumberConstructor | StringConstructor)[];
        default: number;
    };
    vueTransition: {
        type: BooleanConstructor;
        default: boolean;
    };
    transitionName: StringConstructor;
    transitionType: PropType<"transition" | "animation">;
    enter: StringConstructor;
    enterFrom: StringConstructor;
    enterTo: StringConstructor;
    leave: StringConstructor;
    leaveFrom: StringConstructor;
    leaveTo: StringConstructor;
    originClass: PropType<string | ClassResolver>;
    tailwindcssOriginClass: {
        type: BooleanConstructor;
        default: boolean;
    };
    transform: {
        type: BooleanConstructor;
        default: boolean;
    };
    middleware: {
        type: PropType<{
            options?: any;
            name: string;
            fn: (state: {
                x: number;
                y: number;
                strategy: Strategy;
                initialPlacement: Placement;
                placement: Placement;
                middlewareData: import("@floating-ui/core").MiddlewareData;
                rects: import("@floating-ui/utils").ElementRects;
                platform: import("@floating-ui/core").Platform;
                elements: import("@floating-ui/dom").Elements;
            }) => import("@floating-ui/core").MiddlewareReturn | Promise<import("@floating-ui/core").MiddlewareReturn>;
        }[] | ((refs: {
            referenceEl: ComputedRef<ReferenceElement | null>;
            floatingEl: ComputedRef<FloatingElement | null>;
        }) => Middleware[])>;
        default: () => never[];
    };
    globalHideCursor: {
        type: BooleanConstructor;
        default: boolean;
    };
};
export declare const FloatCursor: new () => {
    $props: FloatCursorProps;
    $slots: {
        default(props: FloatVirtualSlotProps): any;
    };
};
export {};
